"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sha256 = exports.isPlayIntegrityAvailable = exports.googleAttestation = exports.generateKey = exports.appleKeyAttestation = exports.appleAttestation = void 0;
var _reactNative = require("react-native");
var _buffer = require("buffer");
var _NativeAttestation = _interopRequireDefault(require("./NativeAttestation"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const LINKING_ERROR = `The package 'react-native-attestation' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';

// @ts-expect-error global.__turboModuleProxy is a global variable injected by TurboModuleProxy
const isTurboModuleEnabled = global.__turboModuleProxy != null;
const AttestationModule = isTurboModuleEnabled ? _NativeAttestation.default : _reactNative.NativeModules.Attestation;
const Attestation = AttestationModule ? AttestationModule : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});

// TODO: Make available from Android.
const sha256 = async stringToHash => {
  if (_reactNative.Platform.OS !== 'ios') {
    throw new Error('sha256 is only available on iOS');
  }
  const bytes = await Attestation.sha256(stringToHash);
  return _buffer.Buffer.from(bytes);
};
exports.sha256 = sha256;
const generateKey = async (cache = false) => {
  if (_reactNative.Platform.OS !== 'ios') {
    throw new Error('generateKey is only available on iOS');
  }
  return Attestation.generateKey(cache);
};
exports.generateKey = generateKey;
const appleKeyAttestation = async (keyId, challenge) => {
  if (_reactNative.Platform.OS !== 'ios') {
    throw new Error('appleKeyAttestation is only available on iOS');
  }
  const bytes = await Attestation.appleKeyAttestation(keyId, challenge);
  return _buffer.Buffer.from(bytes);
};
exports.appleKeyAttestation = appleKeyAttestation;
const appleAttestation = async (keyId, challenge) => {
  if (_reactNative.Platform.OS !== 'ios') {
    throw new Error('appleAttestation is only available on iOS');
  }
  const bytes = await Attestation.appleAttestation(keyId, challenge);
  return _buffer.Buffer.from(bytes);
};
exports.appleAttestation = appleAttestation;
const googleAttestation = async nonce => {
  if (_reactNative.Platform.OS !== 'android') {
    throw new Error('googleAttestation is only available on Android');
  }
  const token = await Attestation.googleAttestation(nonce);
  return token;
};
exports.googleAttestation = googleAttestation;
const isPlayIntegrityAvailable = async () => {
  if (_reactNative.Platform.OS !== 'android') {
    throw new Error('isPlayIntegrityAvailable is only available on Android');
  }
  return Attestation.isPlayIntegrityAvailable();
};
exports.isPlayIntegrityAvailable = isPlayIntegrityAvailable;
//# sourceMappingURL=index.js.map